@@ -1,7 +1,7 @@
 # ABSTRACT: Keeps track of progress status
 
 package Dancer2::Plugin::ProgressStatus;
-$Dancer2::Plugin::ProgressStatus::VERSION = '0.017';
+$Dancer2::Plugin::ProgressStatus::VERSION = '0.018';
 use strict;
 use warnings;
 
@@ -18,7 +18,7 @@ use Dancer2::Core::Response;
 sub _progress_status_file {
     my ( $dsl, $name ) = @_;
 
-    my $dir = $dsl->config->{'plugins'}->{ProgressStatus}->{dir}
+    my $dir = $dsl->app->config->{'plugins'}{ProgressStatus}{dir}
                 or croak 'No ProgressStatus plugin settings in config';
     if ( !-d $dir ) {
         File::Path::make_path($dir) or die "Cannot create path $dir";
@@ -161,7 +161,7 @@ Dancer2::Plugin::ProgressStatus - Keeps track of progress status
 
 =head1 VERSION
 
-version 0.017
+version 0.018
 
 =head1 SYNOPSIS
 
